# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.task_group_response import TaskGroupResponse

class TestTaskGroupResponse(unittest.TestCase):
    """TaskGroupResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TaskGroupResponse:
        """Test TaskGroupResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TaskGroupResponse`
        """
        model = TaskGroupResponse()
        if include_optional:
            return TaskGroupResponse(
                pulp_href = '',
                prn = '',
                description = '',
                all_tasks_dispatched = True,
                waiting = 56,
                skipped = 56,
                running = 56,
                completed = 56,
                canceled = 56,
                failed = 56,
                canceling = 56,
                group_progress_reports = [
                    crc-pulpcore-client.models.group_progress_report_response.GroupProgressReportResponse(
                        message = '', 
                        code = '', 
                        total = 56, 
                        done = 56, 
                        suffix = '', )
                    ],
                tasks = [
                    crc-pulpcore-client.models.minimal_task_response.MinimalTaskResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        state = '', 
                        unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        worker = '', )
                    ]
            )
        else:
            return TaskGroupResponse(
                description = '',
                all_tasks_dispatched = True,
        )
        """

    def testTaskGroupResponse(self):
        """Test TaskGroupResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class StatesEnum(str, Enum):
    """
    * `skipped` - skipped * `completed` - completed * `failed` - failed * `canceled` - canceled
    """

    """
    allowed enum values
    """
    SKIPPED = 'skipped'
    COMPLETED = 'completed'
    FAILED = 'failed'
    CANCELED = 'canceled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of StatesEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.generic_remote_response_policy_enum import GenericRemoteResponsePolicyEnum

class TestGenericRemoteResponsePolicyEnum(unittest.TestCase):
    """GenericRemoteResponsePolicyEnum unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testGenericRemoteResponsePolicyEnum(self):
        """Test GenericRemoteResponsePolicyEnum"""
        # inst = GenericRemoteResponsePolicyEnum()

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.open_pgp_user_id_response import OpenPGPUserIDResponse

class TestOpenPGPUserIDResponse(unittest.TestCase):
    """OpenPGPUserIDResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> OpenPGPUserIDResponse:
        """Test OpenPGPUserIDResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `OpenPGPUserIDResponse`
        """
        model = OpenPGPUserIDResponse()
        if include_optional:
            return OpenPGPUserIDResponse(
                pulp_href = '',
                prn = '',
                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                pulp_labels = {
                    'key' : ''
                    },
                user_id = '',
                signatures = [
                    crc-pulpcore-client.models.nested_open_pgp_signature_response.NestedOpenPGPSignatureResponse(
                        issuer = '', 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        expiration_time = '', 
                        signers_user_id = '', 
                        key_expiration_time = '', 
                        expired = True, 
                        key_expired = '', )
                    ],
                public_key = ''
            )
        else:
            return OpenPGPUserIDResponse(
                user_id = '',
        )
        """

    def testOpenPGPUserIDResponse(self):
        """Test OpenPGPUserIDResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from pydantic import Field, StrictFloat, StrictInt, StrictStr, field_validator
from typing import List, Optional, Union
from typing_extensions import Annotated
from crc-pulpcore-client.models.open_pgp_public_subkey_response import OpenPGPPublicSubkeyResponse
from crc-pulpcore-client.models.paginated_open_pgp_public_subkey_response_list import PaginatedOpenPGPPublicSubkeyResponseList
from crc-pulpcore-client.models.set_label import SetLabel
from crc-pulpcore-client.models.set_label_response import SetLabelResponse
from crc-pulpcore-client.models.unset_label import UnsetLabel
from crc-pulpcore-client.models.unset_label_response import UnsetLabelResponse

from crc-pulpcore-client.api_client import ApiClient, RequestSerialized
from crc-pulpcore-client.api_response import ApiResponse
from crc-pulpcore-client.rest import RESTResponseType


class ContentOpenpgpPublicsubkeyApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def list(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fingerprint: Annotated[Optional[StrictStr], Field(description="Filter results where fingerprint matches value")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> PaginatedOpenPGPPublicSubkeyResponseList:
        """List open pgp public subkeys

        Content viewset that supports only GET by default.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fingerprint: Filter results where fingerprint matches value
        :type fingerprint: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            fingerprint=fingerprint,
            limit=limit,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedOpenPGPPublicSubkeyResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def list_with_http_info(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fingerprint: Annotated[Optional[StrictStr], Field(description="Filter results where fingerprint matches value")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[PaginatedOpenPGPPublicSubkeyResponseList]:
        """List open pgp public subkeys

        Content viewset that supports only GET by default.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fingerprint: Filter results where fingerprint matches value
        :type fingerprint: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            fingerprint=fingerprint,
            limit=limit,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedOpenPGPPublicSubkeyResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def list_without_preload_content(
        self,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fingerprint: Annotated[Optional[StrictStr], Field(description="Filter results where fingerprint matches value")] = None,
        limit: Annotated[Optional[StrictInt], Field(description="Number of results to return per page.")] = None,
        offset: Annotated[Optional[StrictInt], Field(description="The initial index from which to return the results.")] = None,
        ordering: Annotated[Optional[List[StrictStr]], Field(description="Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)")] = None,
        orphaned_for: Annotated[Optional[Union[StrictFloat, StrictInt]], Field(description="Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.")] = None,
        prn__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_href__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_id__in: Annotated[Optional[List[StrictStr]], Field(description="Multiple values may be separated by commas.")] = None,
        pulp_label_select: Annotated[Optional[StrictStr], Field(description="Filter labels by search string")] = None,
        q: Annotated[Optional[StrictStr], Field(description="Filter results by using NOT, AND and OR operations on other filters")] = None,
        repository_version: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_added: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        repository_version_removed: Annotated[Optional[StrictStr], Field(description="Repository Version referenced by HREF/PRN")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        pulp_domain: StrictStr = "default",
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """List open pgp public subkeys

        Content viewset that supports only GET by default.

        :param pulp_domain: (required)
        :type pulp_domain: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fingerprint: Filter results where fingerprint matches value
        :type fingerprint: str
        :param limit: Number of results to return per page.
        :type limit: int
        :param offset: The initial index from which to return the results.
        :type offset: int
        :param ordering: Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `pulp_labels` - Pulp labels * `-pulp_labels` - Pulp labels (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `raw_data` - Raw data * `-raw_data` - Raw data (descending) * `fingerprint` - Fingerprint * `-fingerprint` - Fingerprint (descending) * `created` - Created * `-created` - Created (descending) * `pk` - Pk * `-pk` - Pk (descending)
        :type ordering: List[str]
        :param orphaned_for: Minutes Content has been orphaned for. -1 uses ORPHAN_PROTECTION_TIME.
        :type orphaned_for: float
        :param prn__in: Multiple values may be separated by commas.
        :type prn__in: List[str]
        :param pulp_href__in: Multiple values may be separated by commas.
        :type pulp_href__in: List[str]
        :param pulp_id__in: Multiple values may be separated by commas.
        :type pulp_id__in: List[str]
        :param pulp_label_select: Filter labels by search string
        :type pulp_label_select: str
        :param q: Filter results by using NOT, AND and OR operations on other filters
        :type q: str
        :param repository_version: Repository Version referenced by HREF/PRN
        :type repository_version: str
        :param repository_version_added: Repository Version referenced by HREF/PRN
        :type repository_version_added: str
        :param repository_version_removed: Repository Version referenced by HREF/PRN
        :type repository_version_removed: str
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._list_serialize(
            pulp_domain=pulp_domain,
            x_task_diagnostics=x_task_diagnostics,
            fingerprint=fingerprint,
            limit=limit,
            offset=offset,
            ordering=ordering,
            orphaned_for=orphaned_for,
            prn__in=prn__in,
            pulp_href__in=pulp_href__in,
            pulp_id__in=pulp_id__in,
            pulp_label_select=pulp_label_select,
            q=q,
            repository_version=repository_version,
            repository_version_added=repository_version_added,
            repository_version_removed=repository_version_removed,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "PaginatedOpenPGPPublicSubkeyResponseList",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _list_serialize(
        self,
        pulp_domain,
        x_task_diagnostics,
        fingerprint,
        limit,
        offset,
        ordering,
        orphaned_for,
        prn__in,
        pulp_href__in,
        pulp_id__in,
        pulp_label_select,
        q,
        repository_version,
        repository_version_added,
        repository_version_removed,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'ordering': 'csv',
            'prn__in': 'csv',
            'pulp_href__in': 'csv',
            'pulp_id__in': 'csv',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if pulp_domain is not None:
            _path_params['pulp_domain'] = pulp_domain
        # process the query parameters
        if fingerprint is not None:
            
            _query_params.append(('fingerprint', fingerprint))
            
        if limit is not None:
            
            _query_params.append(('limit', limit))
            
        if offset is not None:
            
            _query_params.append(('offset', offset))
            
        if ordering is not None:
            
            _query_params.append(('ordering', ordering))
            
        if orphaned_for is not None:
            
            _query_params.append(('orphaned_for', orphaned_for))
            
        if prn__in is not None:
            
            _query_params.append(('prn__in', prn__in))
            
        if pulp_href__in is not None:
            
            _query_params.append(('pulp_href__in', pulp_href__in))
            
        if pulp_id__in is not None:
            
            _query_params.append(('pulp_id__in', pulp_id__in))
            
        if pulp_label_select is not None:
            
            _query_params.append(('pulp_label_select', pulp_label_select))
            
        if q is not None:
            
            _query_params.append(('q', q))
            
        if repository_version is not None:
            
            _query_params.append(('repository_version', repository_version))
            
        if repository_version_added is not None:
            
            _query_params.append(('repository_version_added', repository_version_added))
            
        if repository_version_removed is not None:
            
            _query_params.append(('repository_version_removed', repository_version_removed))
            
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'json_header_remote_authentication', 
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/api/pulp/{pulp_domain}/api/v3/content/core/openpgp_publicsubkey/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def read(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> OpenPGPPublicSubkeyResponse:
        """Inspect an open pgp public subkey

        Content viewset that supports only GET by default.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OpenPGPPublicSubkeyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def read_with_http_info(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[OpenPGPPublicSubkeyResponse]:
        """Inspect an open pgp public subkey

        Content viewset that supports only GET by default.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OpenPGPPublicSubkeyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def read_without_preload_content(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to include in the response.")] = None,
        exclude_fields: Annotated[Optional[List[StrictStr]], Field(description="A list of fields to exclude from the response.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Inspect an open pgp public subkey

        Content viewset that supports only GET by default.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param fields: A list of fields to include in the response.
        :type fields: List[str]
        :param exclude_fields: A list of fields to exclude from the response.
        :type exclude_fields: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._read_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            x_task_diagnostics=x_task_diagnostics,
            fields=fields,
            exclude_fields=exclude_fields,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "OpenPGPPublicSubkeyResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _read_serialize(
        self,
        open_p_g_p_public_subkey_href,
        x_task_diagnostics,
        fields,
        exclude_fields,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
            'fields': 'multi',
            'exclude_fields': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if open_p_g_p_public_subkey_href is not None:
            _path_params['open_p_g_p_public_subkey_href'] = open_p_g_p_public_subkey_href
        # process the query parameters
        if fields is not None:
            
            _query_params.append(('fields', fields))
            
        if exclude_fields is not None:
            
            _query_params.append(('exclude_fields', exclude_fields))
            
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'json_header_remote_authentication', 
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='{open_p_g_p_public_subkey_href}',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def set_label(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        set_label: SetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> SetLabelResponse:
        """Set a label

        Set a single pulp_label on the object to a specific value or null.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param set_label: (required)
        :type set_label: SetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            set_label=set_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def set_label_with_http_info(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        set_label: SetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[SetLabelResponse]:
        """Set a label

        Set a single pulp_label on the object to a specific value or null.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param set_label: (required)
        :type set_label: SetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            set_label=set_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def set_label_without_preload_content(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        set_label: SetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Set a label

        Set a single pulp_label on the object to a specific value or null.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param set_label: (required)
        :type set_label: SetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._set_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            set_label=set_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "SetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _set_label_serialize(
        self,
        open_p_g_p_public_subkey_href,
        set_label,
        x_task_diagnostics,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if open_p_g_p_public_subkey_href is not None:
            _path_params['open_p_g_p_public_subkey_href'] = open_p_g_p_public_subkey_href
        # process the query parameters
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter
        if set_label is not None:
            _body_params = set_label


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'json_header_remote_authentication', 
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='{open_p_g_p_public_subkey_href}set_label/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def unset_label(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        unset_label: UnsetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> UnsetLabelResponse:
        """Unset a label

        Unset a single pulp_label on the object.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param unset_label: (required)
        :type unset_label: UnsetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unset_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            unset_label=unset_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UnsetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def unset_label_with_http_info(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        unset_label: UnsetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[UnsetLabelResponse]:
        """Unset a label

        Unset a single pulp_label on the object.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param unset_label: (required)
        :type unset_label: UnsetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unset_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            unset_label=unset_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UnsetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def unset_label_without_preload_content(
        self,
        open_p_g_p_public_subkey_href: StrictStr,
        unset_label: UnsetLabel,
        x_task_diagnostics: Annotated[Optional[List[StrictStr]], Field(description="List of profilers to use on tasks.")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Unset a label

        Unset a single pulp_label on the object.

        :param open_p_g_p_public_subkey_href: (required)
        :type open_p_g_p_public_subkey_href: str
        :param unset_label: (required)
        :type unset_label: UnsetLabel
        :param x_task_diagnostics: List of profilers to use on tasks.
        :type x_task_diagnostics: List[str]
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._unset_label_serialize(
            open_p_g_p_public_subkey_href=open_p_g_p_public_subkey_href,
            unset_label=unset_label,
            x_task_diagnostics=x_task_diagnostics,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "UnsetLabelResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _unset_label_serialize(
        self,
        open_p_g_p_public_subkey_href,
        unset_label,
        x_task_diagnostics,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'X-Task-Diagnostics': 'csv',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if open_p_g_p_public_subkey_href is not None:
            _path_params['open_p_g_p_public_subkey_href'] = open_p_g_p_public_subkey_href
        # process the query parameters
        # process the header parameters
        if x_task_diagnostics is not None:
            _header_params['X-Task-Diagnostics'] = x_task_diagnostics
        # process the form parameters
        # process the body parameter
        if unset_label is not None:
            _body_params = unset_label


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json', 
                        'application/x-www-form-urlencoded', 
                        'multipart/form-data'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'json_header_remote_authentication', 
            'basicAuth', 
            'cookieAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='{open_p_g_p_public_subkey_href}unset_label/',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class OrphansCleanup(BaseModel):
    """
    OrphansCleanup
    """ # noqa: E501
    content_hrefs: Optional[List[Any]] = Field(default=None, description="Will delete specified content and associated Artifacts if they are orphans.")
    orphan_protection_time: Optional[Annotated[int, Field(le=4294967295, strict=True, ge=0)]] = Field(default=None, description="The time in minutes for how long Pulp will hold orphan Content and Artifacts before they become candidates for deletion by this orphan cleanup task. This should ideally be longer than your longest running task otherwise any content created during that task could be cleaned up before the task finishes. If not specified, a default value is taken from the setting ORPHAN_PROTECTION_TIME.")
    __properties: ClassVar[List[str]] = ["content_hrefs", "orphan_protection_time"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of OrphansCleanup from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if orphan_protection_time (nullable) is None
        # and model_fields_set contains the field
        if self.orphan_protection_time is None and "orphan_protection_time" in self.model_fields_set:
            _dict['orphan_protection_time'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of OrphansCleanup from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "content_hrefs": obj.get("content_hrefs"),
            "orphan_protection_time": obj.get("orphan_protection_time")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.paginated_task_response_list import PaginatedTaskResponseList

class TestPaginatedTaskResponseList(unittest.TestCase):
    """PaginatedTaskResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedTaskResponseList:
        """Test PaginatedTaskResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedTaskResponseList`
        """
        model = PaginatedTaskResponseList()
        if include_optional:
            return PaginatedTaskResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    crc-pulpcore-client.models.task_response.TaskResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        state = '', 
                        name = '', 
                        logging_cid = '', 
                        created_by = '', 
                        unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error = crc-pulpcore-client.models.error.error(), 
                        worker = '', 
                        parent_task = '', 
                        child_tasks = [
                            ''
                            ], 
                        task_group = '', 
                        progress_reports = [
                            crc-pulpcore-client.models.progress_report_response.ProgressReportResponse(
                                message = '', 
                                code = '', 
                                state = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        created_resources = [
                            ''
                            ], 
                        reserved_resources_record = [
                            ''
                            ], )
                    ]
            )
        else:
            return PaginatedTaskResponseList(
                count = 123,
                results = [
                    crc-pulpcore-client.models.task_response.TaskResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        state = '', 
                        name = '', 
                        logging_cid = '', 
                        created_by = '', 
                        unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        error = crc-pulpcore-client.models.error.error(), 
                        worker = '', 
                        parent_task = '', 
                        child_tasks = [
                            ''
                            ], 
                        task_group = '', 
                        progress_reports = [
                            crc-pulpcore-client.models.progress_report_response.ProgressReportResponse(
                                message = '', 
                                code = '', 
                                state = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        created_resources = [
                            ''
                            ], 
                        reserved_resources_record = [
                            ''
                            ], )
                    ],
        )
        """

    def testPaginatedTaskResponseList(self):
        """Test PaginatedTaskResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.paginated_task_group_response_list import PaginatedTaskGroupResponseList

class TestPaginatedTaskGroupResponseList(unittest.TestCase):
    """PaginatedTaskGroupResponseList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedTaskGroupResponseList:
        """Test PaginatedTaskGroupResponseList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedTaskGroupResponseList`
        """
        model = PaginatedTaskGroupResponseList()
        if include_optional:
            return PaginatedTaskGroupResponseList(
                count = 123,
                next = 'http://api.example.org/accounts/?offset=400&limit=100',
                previous = 'http://api.example.org/accounts/?offset=200&limit=100',
                results = [
                    crc-pulpcore-client.models.task_group_response.TaskGroupResponse(
                        pulp_href = '', 
                        prn = '', 
                        description = '', 
                        all_tasks_dispatched = True, 
                        waiting = 56, 
                        skipped = 56, 
                        running = 56, 
                        completed = 56, 
                        canceled = 56, 
                        failed = 56, 
                        canceling = 56, 
                        group_progress_reports = [
                            crc-pulpcore-client.models.group_progress_report_response.GroupProgressReportResponse(
                                message = '', 
                                code = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        tasks = [
                            crc-pulpcore-client.models.minimal_task_response.MinimalTaskResponse(
                                pulp_href = '', 
                                prn = '', 
                                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                state = '', 
                                unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                worker = '', )
                            ], )
                    ]
            )
        else:
            return PaginatedTaskGroupResponseList(
                count = 123,
                results = [
                    crc-pulpcore-client.models.task_group_response.TaskGroupResponse(
                        pulp_href = '', 
                        prn = '', 
                        description = '', 
                        all_tasks_dispatched = True, 
                        waiting = 56, 
                        skipped = 56, 
                        running = 56, 
                        completed = 56, 
                        canceled = 56, 
                        failed = 56, 
                        canceling = 56, 
                        group_progress_reports = [
                            crc-pulpcore-client.models.group_progress_report_response.GroupProgressReportResponse(
                                message = '', 
                                code = '', 
                                total = 56, 
                                done = 56, 
                                suffix = '', )
                            ], 
                        tasks = [
                            crc-pulpcore-client.models.minimal_task_response.MinimalTaskResponse(
                                pulp_href = '', 
                                prn = '', 
                                pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                name = '', 
                                state = '', 
                                unblocked_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                worker = '', )
                            ], )
                    ],
        )
        """

    def testPaginatedTaskGroupResponseList(self):
        """Test PaginatedTaskGroupResponseList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class PulpExport(BaseModel):
    """
    Serializer for PulpExports.
    """ # noqa: E501
    task: Optional[StrictStr] = Field(default=None, description="A URI of the task that ran the Export.")
    full: Optional[StrictBool] = Field(default=True, description="Do a Full (true) or Incremental (false) export.")
    dry_run: Optional[StrictBool] = Field(default=False, description="Generate report on what would be exported and disk-space required.")
    versions: Optional[List[StrictStr]] = Field(default=None, description="List of explicit repo-version hrefs to export (replaces current_version).")
    chunk_size: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="Chunk export-tarfile into pieces of chunk_size bytes. Recognizes units of B/KB/MB/GB/TB. A chunk has a maximum size of 1TB.")
    start_versions: Optional[List[StrictStr]] = Field(default=None, description="List of explicit last-exported-repo-version hrefs (replaces last_export).")
    __properties: ClassVar[List[str]] = ["task", "full", "dry_run", "versions", "chunk_size", "start_versions"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PulpExport from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if task (nullable) is None
        # and model_fields_set contains the field
        if self.task is None and "task" in self.model_fields_set:
            _dict['task'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PulpExport from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "task": obj.get("task"),
            "full": obj.get("full") if obj.get("full") is not None else True,
            "dry_run": obj.get("dry_run") if obj.get("dry_run") is not None else False,
            "versions": obj.get("versions"),
            "chunk_size": obj.get("chunk_size"),
            "start_versions": obj.get("start_versions")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from crc-pulpcore-client.models.api_app_status_response import ApiAppStatusResponse
from crc-pulpcore-client.models.content_app_status_response import ContentAppStatusResponse
from crc-pulpcore-client.models.content_settings_response import ContentSettingsResponse
from crc-pulpcore-client.models.database_connection_response import DatabaseConnectionResponse
from crc-pulpcore-client.models.redis_connection_response import RedisConnectionResponse
from crc-pulpcore-client.models.storage_response import StorageResponse
from crc-pulpcore-client.models.version_response import VersionResponse
from crc-pulpcore-client.models.worker_response import WorkerResponse
from typing import Optional, Set
from typing_extensions import Self

class StatusResponse(BaseModel):
    """
    Serializer for the status information of the app
    """ # noqa: E501
    versions: List[VersionResponse] = Field(description="Version information of Pulp components")
    online_workers: List[WorkerResponse] = Field(description="List of online workers known to the application. An online worker is actively heartbeating and can respond to new work.")
    online_api_apps: List[ApiAppStatusResponse] = Field(description="List of online api apps known to the application. An online api app is actively heartbeating and can serve the rest api to clients.")
    online_content_apps: List[ContentAppStatusResponse] = Field(description="List of online content apps known to the application. An online content app is actively heartbeating and can serve data to clients.")
    database_connection: DatabaseConnectionResponse = Field(description="Database connection information")
    redis_connection: Optional[RedisConnectionResponse] = Field(default=None, description="Redis connection information")
    storage: Optional[StorageResponse] = Field(default=None, description="Storage information")
    content_settings: ContentSettingsResponse = Field(description="Content-app settings")
    domain_enabled: StrictBool = Field(description="Is Domains enabled")
    __properties: ClassVar[List[str]] = ["versions", "online_workers", "online_api_apps", "online_content_apps", "database_connection", "redis_connection", "storage", "content_settings", "domain_enabled"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of StatusResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in versions (list)
        _items = []
        if self.versions:
            for _item_versions in self.versions:
                if _item_versions:
                    _items.append(_item_versions.to_dict())
            _dict['versions'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in online_workers (list)
        _items = []
        if self.online_workers:
            for _item_online_workers in self.online_workers:
                if _item_online_workers:
                    _items.append(_item_online_workers.to_dict())
            _dict['online_workers'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in online_api_apps (list)
        _items = []
        if self.online_api_apps:
            for _item_online_api_apps in self.online_api_apps:
                if _item_online_api_apps:
                    _items.append(_item_online_api_apps.to_dict())
            _dict['online_api_apps'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in online_content_apps (list)
        _items = []
        if self.online_content_apps:
            for _item_online_content_apps in self.online_content_apps:
                if _item_online_content_apps:
                    _items.append(_item_online_content_apps.to_dict())
            _dict['online_content_apps'] = _items
        # override the default output from pydantic by calling `to_dict()` of database_connection
        if self.database_connection:
            _dict['database_connection'] = self.database_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of redis_connection
        if self.redis_connection:
            _dict['redis_connection'] = self.redis_connection.to_dict()
        # override the default output from pydantic by calling `to_dict()` of storage
        if self.storage:
            _dict['storage'] = self.storage.to_dict()
        # override the default output from pydantic by calling `to_dict()` of content_settings
        if self.content_settings:
            _dict['content_settings'] = self.content_settings.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of StatusResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "versions": [VersionResponse.from_dict(_item) for _item in obj["versions"]] if obj.get("versions") is not None else None,
            "online_workers": [WorkerResponse.from_dict(_item) for _item in obj["online_workers"]] if obj.get("online_workers") is not None else None,
            "online_api_apps": [ApiAppStatusResponse.from_dict(_item) for _item in obj["online_api_apps"]] if obj.get("online_api_apps") is not None else None,
            "online_content_apps": [ContentAppStatusResponse.from_dict(_item) for _item in obj["online_content_apps"]] if obj.get("online_content_apps") is not None else None,
            "database_connection": DatabaseConnectionResponse.from_dict(obj["database_connection"]) if obj.get("database_connection") is not None else None,
            "redis_connection": RedisConnectionResponse.from_dict(obj["redis_connection"]) if obj.get("redis_connection") is not None else None,
            "storage": StorageResponse.from_dict(obj["storage"]) if obj.get("storage") is not None else None,
            "content_settings": ContentSettingsResponse.from_dict(obj["content_settings"]) if obj.get("content_settings") is not None else None,
            "domain_enabled": obj.get("domain_enabled")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.status_response import StatusResponse

class TestStatusResponse(unittest.TestCase):
    """StatusResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StatusResponse:
        """Test StatusResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StatusResponse`
        """
        model = StatusResponse()
        if include_optional:
            return StatusResponse(
                versions = [
                    crc-pulpcore-client.models.version_response.VersionResponse(
                        component = '', 
                        version = '', 
                        package = '', 
                        module = '', 
                        domain_compatible = True, )
                    ],
                online_workers = [
                    crc-pulpcore-client.models.worker_response.WorkerResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, 
                        current_task = '', )
                    ],
                online_api_apps = [
                    crc-pulpcore-client.models.api_app_status_response.ApiAppStatusResponse(
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, )
                    ],
                online_content_apps = [
                    crc-pulpcore-client.models.content_app_status_response.ContentAppStatusResponse(
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, )
                    ],
                database_connection = crc-pulpcore-client.models.database_connection_response.DatabaseConnectionResponse(
                    connected = True, ),
                redis_connection = crc-pulpcore-client.models.redis_connection_response.RedisConnectionResponse(
                    connected = True, ),
                storage = crc-pulpcore-client.models.storage_response.StorageResponse(
                    total = 0, 
                    used = 0, 
                    free = 0, ),
                content_settings = crc-pulpcore-client.models.content_settings_response.ContentSettingsResponse(
                    content_origin = '', 
                    content_path_prefix = '', ),
                domain_enabled = True
            )
        else:
            return StatusResponse(
                versions = [
                    crc-pulpcore-client.models.version_response.VersionResponse(
                        component = '', 
                        version = '', 
                        package = '', 
                        module = '', 
                        domain_compatible = True, )
                    ],
                online_workers = [
                    crc-pulpcore-client.models.worker_response.WorkerResponse(
                        pulp_href = '', 
                        prn = '', 
                        pulp_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        pulp_last_updated = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, 
                        current_task = '', )
                    ],
                online_api_apps = [
                    crc-pulpcore-client.models.api_app_status_response.ApiAppStatusResponse(
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, )
                    ],
                online_content_apps = [
                    crc-pulpcore-client.models.content_app_status_response.ContentAppStatusResponse(
                        name = '', 
                        last_heartbeat = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        versions = {
                            'key' : ''
                            }, )
                    ],
                database_connection = crc-pulpcore-client.models.database_connection_response.DatabaseConnectionResponse(
                    connected = True, ),
                content_settings = crc-pulpcore-client.models.content_settings_response.ContentSettingsResponse(
                    content_origin = '', 
                    content_path_prefix = '', ),
                domain_enabled = True,
        )
        """

    def testStatusResponse(self):
        """Test StatusResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class MethodEnum(str, Enum):
    """
    * `write` - Export by writing * `hardlink` - Export by hardlinking * `symlink` - Export by symlinking
    """

    """
    allowed enum values
    """
    WRITE = 'write'
    HARDLINK = 'hardlink'
    SYMLINK = 'symlink'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of MethodEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from crc-pulpcore-client.models.group_progress_report_response import GroupProgressReportResponse
from crc-pulpcore-client.models.minimal_task_response import MinimalTaskResponse
from typing import Optional, Set
from typing_extensions import Self

class TaskGroupResponse(BaseModel):
    """
    Base serializer for use with [pulpcore.app.models.Model][]  This ensures that all Serializers provide values for the 'pulp_href` field.  The class provides a default for the ``ref_name`` attribute in the ModelSerializers's ``Meta`` class. This ensures that the OpenAPI definitions of plugins are namespaced properly.
    """ # noqa: E501
    pulp_href: Optional[StrictStr] = None
    prn: Optional[StrictStr] = Field(default=None, description="The Pulp Resource Name (PRN).")
    description: StrictStr = Field(description="A description of the task group.")
    all_tasks_dispatched: StrictBool = Field(description="Whether all tasks have been spawned for this task group.")
    waiting: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'waiting' state")
    skipped: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'skipped' state")
    running: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'running' state")
    completed: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'completed' state")
    canceled: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'canceled' state")
    failed: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'failed' state")
    canceling: Optional[StrictInt] = Field(default=None, description="Number of tasks in the 'canceling' state")
    group_progress_reports: Optional[List[GroupProgressReportResponse]] = None
    tasks: Optional[List[MinimalTaskResponse]] = None
    __properties: ClassVar[List[str]] = ["pulp_href", "prn", "description", "all_tasks_dispatched", "waiting", "skipped", "running", "completed", "canceled", "failed", "canceling", "group_progress_reports", "tasks"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TaskGroupResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pulp_href",
            "prn",
            "waiting",
            "skipped",
            "running",
            "completed",
            "canceled",
            "failed",
            "canceling",
            "group_progress_reports",
            "tasks",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in group_progress_reports (list)
        _items = []
        if self.group_progress_reports:
            for _item_group_progress_reports in self.group_progress_reports:
                if _item_group_progress_reports:
                    _items.append(_item_group_progress_reports.to_dict())
            _dict['group_progress_reports'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in tasks (list)
        _items = []
        if self.tasks:
            for _item_tasks in self.tasks:
                if _item_tasks:
                    _items.append(_item_tasks.to_dict())
            _dict['tasks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TaskGroupResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pulp_href": obj.get("pulp_href"),
            "prn": obj.get("prn"),
            "description": obj.get("description"),
            "all_tasks_dispatched": obj.get("all_tasks_dispatched"),
            "waiting": obj.get("waiting"),
            "skipped": obj.get("skipped"),
            "running": obj.get("running"),
            "completed": obj.get("completed"),
            "canceled": obj.get("canceled"),
            "failed": obj.get("failed"),
            "canceling": obj.get("canceling"),
            "group_progress_reports": [GroupProgressReportResponse.from_dict(_item) for _item in obj["group_progress_reports"]] if obj.get("group_progress_reports") is not None else None,
            "tasks": [MinimalTaskResponse.from_dict(_item) for _item in obj["tasks"]] if obj.get("tasks") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from crc-pulpcore-client.models.upstream_pulp import UpstreamPulp

class TestUpstreamPulp(unittest.TestCase):
    """UpstreamPulp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UpstreamPulp:
        """Test UpstreamPulp
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UpstreamPulp`
        """
        model = UpstreamPulp()
        if include_optional:
            return UpstreamPulp(
                name = '0',
                base_url = '0',
                api_root = '0',
                domain = '0',
                ca_cert = '0',
                client_cert = '0',
                client_key = '0',
                tls_validation = True,
                username = '0',
                password = '0',
                q_select = '',
                policy = 'all'
            )
        else:
            return UpstreamPulp(
                name = '0',
                base_url = '0',
                api_root = '0',
        )
        """

    def testUpstreamPulp(self):
        """Test UpstreamPulp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from crc-pulpcore-client.models.access_policy import AccessPolicy
from crc-pulpcore-client.models.access_policy_response import AccessPolicyResponse
from crc-pulpcore-client.models.api_app_status_response import ApiAppStatusResponse
from crc-pulpcore-client.models.artifact_distribution_response import ArtifactDistributionResponse
from crc-pulpcore-client.models.artifact_response import ArtifactResponse
from crc-pulpcore-client.models.async_operation_response import AsyncOperationResponse
from crc-pulpcore-client.models.composite_content_guard import CompositeContentGuard
from crc-pulpcore-client.models.composite_content_guard_response import CompositeContentGuardResponse
from crc-pulpcore-client.models.content_app_status_response import ContentAppStatusResponse
from crc-pulpcore-client.models.content_guard_response import ContentGuardResponse
from crc-pulpcore-client.models.content_redirect_content_guard import ContentRedirectContentGuard
from crc-pulpcore-client.models.content_redirect_content_guard_response import ContentRedirectContentGuardResponse
from crc-pulpcore-client.models.content_settings_response import ContentSettingsResponse
from crc-pulpcore-client.models.content_summary_response import ContentSummaryResponse
from crc-pulpcore-client.models.database_connection_response import DatabaseConnectionResponse
from crc-pulpcore-client.models.distribution_response import DistributionResponse
from crc-pulpcore-client.models.domain import Domain
from crc-pulpcore-client.models.domain_backend_migrator import DomainBackendMigrator
from crc-pulpcore-client.models.domain_response import DomainResponse
from crc-pulpcore-client.models.evaluation_response import EvaluationResponse
from crc-pulpcore-client.models.filesystem_export import FilesystemExport
from crc-pulpcore-client.models.filesystem_export_response import FilesystemExportResponse
from crc-pulpcore-client.models.filesystem_exporter import FilesystemExporter
from crc-pulpcore-client.models.filesystem_exporter_response import FilesystemExporterResponse
from crc-pulpcore-client.models.generic_remote_response import GenericRemoteResponse
from crc-pulpcore-client.models.generic_remote_response_hidden_fields_inner import GenericRemoteResponseHiddenFieldsInner
from crc-pulpcore-client.models.generic_remote_response_policy_enum import GenericRemoteResponsePolicyEnum
from crc-pulpcore-client.models.group import Group
from crc-pulpcore-client.models.group_progress_report_response import GroupProgressReportResponse
from crc-pulpcore-client.models.group_response import GroupResponse
from crc-pulpcore-client.models.group_role import GroupRole
from crc-pulpcore-client.models.group_role_response import GroupRoleResponse
from crc-pulpcore-client.models.group_user import GroupUser
from crc-pulpcore-client.models.group_user_response import GroupUserResponse
from crc-pulpcore-client.models.header_content_guard import HeaderContentGuard
from crc-pulpcore-client.models.header_content_guard_response import HeaderContentGuardResponse
from crc-pulpcore-client.models.import_response import ImportResponse
from crc-pulpcore-client.models.login_response import LoginResponse
from crc-pulpcore-client.models.method_enum import MethodEnum
from crc-pulpcore-client.models.minimal_task_response import MinimalTaskResponse
from crc-pulpcore-client.models.multiple_artifact_content_response import MultipleArtifactContentResponse
from crc-pulpcore-client.models.my_permissions_response import MyPermissionsResponse
from crc-pulpcore-client.models.nested_open_pgp_public_subkey import NestedOpenPGPPublicSubkey
from crc-pulpcore-client.models.nested_open_pgp_public_subkey_response import NestedOpenPGPPublicSubkeyResponse
from crc-pulpcore-client.models.nested_open_pgp_signature import NestedOpenPGPSignature
from crc-pulpcore-client.models.nested_open_pgp_signature_response import NestedOpenPGPSignatureResponse
from crc-pulpcore-client.models.nested_open_pgp_user_attribute import NestedOpenPGPUserAttribute
from crc-pulpcore-client.models.nested_open_pgp_user_attribute_response import NestedOpenPGPUserAttributeResponse
from crc-pulpcore-client.models.nested_open_pgp_user_id import NestedOpenPGPUserID
from crc-pulpcore-client.models.nested_open_pgp_user_id_response import NestedOpenPGPUserIDResponse
from crc-pulpcore-client.models.nested_role import NestedRole
from crc-pulpcore-client.models.nested_role_response import NestedRoleResponse
from crc-pulpcore-client.models.object_roles_response import ObjectRolesResponse
from crc-pulpcore-client.models.open_pgp_distribution import OpenPGPDistribution
from crc-pulpcore-client.models.open_pgp_distribution_response import OpenPGPDistributionResponse
from crc-pulpcore-client.models.open_pgp_keyring import OpenPGPKeyring
from crc-pulpcore-client.models.open_pgp_keyring_response import OpenPGPKeyringResponse
from crc-pulpcore-client.models.open_pgp_public_key_response import OpenPGPPublicKeyResponse
from crc-pulpcore-client.models.open_pgp_public_subkey_response import OpenPGPPublicSubkeyResponse
from crc-pulpcore-client.models.open_pgp_signature_response import OpenPGPSignatureResponse
from crc-pulpcore-client.models.open_pgp_user_attribute_response import OpenPGPUserAttributeResponse
from crc-pulpcore-client.models.open_pgp_user_id_response import OpenPGPUserIDResponse
from crc-pulpcore-client.models.orphans_cleanup import OrphansCleanup
from crc-pulpcore-client.models.paginated_access_policy_response_list import PaginatedAccessPolicyResponseList
from crc-pulpcore-client.models.paginated_artifact_distribution_response_list import PaginatedArtifactDistributionResponseList
from crc-pulpcore-client.models.paginated_artifact_response_list import PaginatedArtifactResponseList
from crc-pulpcore-client.models.paginated_composite_content_guard_response_list import PaginatedCompositeContentGuardResponseList
from crc-pulpcore-client.models.paginated_content_guard_response_list import PaginatedContentGuardResponseList
from crc-pulpcore-client.models.paginated_content_redirect_content_guard_response_list import PaginatedContentRedirectContentGuardResponseList
from crc-pulpcore-client.models.paginated_distribution_response_list import PaginatedDistributionResponseList
from crc-pulpcore-client.models.paginated_domain_response_list import PaginatedDomainResponseList
from crc-pulpcore-client.models.paginated_filesystem_export_response_list import PaginatedFilesystemExportResponseList
from crc-pulpcore-client.models.paginated_filesystem_exporter_response_list import PaginatedFilesystemExporterResponseList
from crc-pulpcore-client.models.paginated_generic_remote_response_list import PaginatedGenericRemoteResponseList
from crc-pulpcore-client.models.paginated_group_response_list import PaginatedGroupResponseList
from crc-pulpcore-client.models.paginated_group_role_response_list import PaginatedGroupRoleResponseList
from crc-pulpcore-client.models.paginated_group_user_response_list import PaginatedGroupUserResponseList
from crc-pulpcore-client.models.paginated_header_content_guard_response_list import PaginatedHeaderContentGuardResponseList
from crc-pulpcore-client.models.paginated_import_response_list import PaginatedImportResponseList
from crc-pulpcore-client.models.paginated_multiple_artifact_content_response_list import PaginatedMultipleArtifactContentResponseList
from crc-pulpcore-client.models.paginated_open_pgp_distribution_response_list import PaginatedOpenPGPDistributionResponseList
from crc-pulpcore-client.models.paginated_open_pgp_keyring_response_list import PaginatedOpenPGPKeyringResponseList
from crc-pulpcore-client.models.paginated_open_pgp_public_key_response_list import PaginatedOpenPGPPublicKeyResponseList
from crc-pulpcore-client.models.paginated_open_pgp_public_subkey_response_list import PaginatedOpenPGPPublicSubkeyResponseList
from crc-pulpcore-client.models.paginated_open_pgp_signature_response_list import PaginatedOpenPGPSignatureResponseList
from crc-pulpcore-client.models.paginated_open_pgp_user_attribute_response_list import PaginatedOpenPGPUserAttributeResponseList
from crc-pulpcore-client.models.paginated_open_pgp_user_id_response_list import PaginatedOpenPGPUserIDResponseList
from crc-pulpcore-client.models.paginated_publication_response_list import PaginatedPublicationResponseList
from crc-pulpcore-client.models.paginated_pulp_export_response_list import PaginatedPulpExportResponseList
from crc-pulpcore-client.models.paginated_pulp_exporter_response_list import PaginatedPulpExporterResponseList
from crc-pulpcore-client.models.paginated_pulp_importer_response_list import PaginatedPulpImporterResponseList
from crc-pulpcore-client.models.paginated_rbac_content_guard_response_list import PaginatedRBACContentGuardResponseList
from crc-pulpcore-client.models.paginated_repository_response_list import PaginatedRepositoryResponseList
from crc-pulpcore-client.models.paginated_repository_version_response_list import PaginatedRepositoryVersionResponseList
from crc-pulpcore-client.models.paginated_role_response_list import PaginatedRoleResponseList
from crc-pulpcore-client.models.paginated_signing_service_response_list import PaginatedSigningServiceResponseList
from crc-pulpcore-client.models.paginated_task_group_response_list import PaginatedTaskGroupResponseList
from crc-pulpcore-client.models.paginated_task_response_list import PaginatedTaskResponseList
from crc-pulpcore-client.models.paginated_task_schedule_response_list import PaginatedTaskScheduleResponseList
from crc-pulpcore-client.models.paginated_upload_response_list import PaginatedUploadResponseList
from crc-pulpcore-client.models.paginated_upstream_pulp_response_list import PaginatedUpstreamPulpResponseList
from crc-pulpcore-client.models.paginated_user_response_list import PaginatedUserResponseList
from crc-pulpcore-client.models.paginated_user_role_response_list import PaginatedUserRoleResponseList
from crc-pulpcore-client.models.paginated_worker_response_list import PaginatedWorkerResponseList
from crc-pulpcore-client.models.patched_access_policy import PatchedAccessPolicy
from crc-pulpcore-client.models.patched_composite_content_guard import PatchedCompositeContentGuard
from crc-pulpcore-client.models.patched_content_redirect_content_guard import PatchedContentRedirectContentGuard
from crc-pulpcore-client.models.patched_domain import PatchedDomain
from crc-pulpcore-client.models.patched_filesystem_exporter import PatchedFilesystemExporter
from crc-pulpcore-client.models.patched_group import PatchedGroup
from crc-pulpcore-client.models.patched_header_content_guard import PatchedHeaderContentGuard
from crc-pulpcore-client.models.patched_open_pgp_distribution import PatchedOpenPGPDistribution
from crc-pulpcore-client.models.patched_open_pgp_keyring import PatchedOpenPGPKeyring
from crc-pulpcore-client.models.patched_pulp_exporter import PatchedPulpExporter
from crc-pulpcore-client.models.patched_pulp_importer import PatchedPulpImporter
from crc-pulpcore-client.models.patched_rbac_content_guard import PatchedRBACContentGuard
from crc-pulpcore-client.models.patched_role import PatchedRole
from crc-pulpcore-client.models.patched_task_cancel import PatchedTaskCancel
from crc-pulpcore-client.models.patched_upstream_pulp import PatchedUpstreamPulp
from crc-pulpcore-client.models.patched_user import PatchedUser
from crc-pulpcore-client.models.policy357_enum import Policy357Enum
from crc-pulpcore-client.models.profile_artifact_response import ProfileArtifactResponse
from crc-pulpcore-client.models.progress_report_response import ProgressReportResponse
from crc-pulpcore-client.models.publication_response import PublicationResponse
from crc-pulpcore-client.models.pulp_export import PulpExport
from crc-pulpcore-client.models.pulp_export_response import PulpExportResponse
from crc-pulpcore-client.models.pulp_exporter import PulpExporter
from crc-pulpcore-client.models.pulp_exporter_response import PulpExporterResponse
from crc-pulpcore-client.models.pulp_import import PulpImport
from crc-pulpcore-client.models.pulp_import_check import PulpImportCheck
from crc-pulpcore-client.models.pulp_import_check_response import PulpImportCheckResponse
from crc-pulpcore-client.models.pulp_importer import PulpImporter
from crc-pulpcore-client.models.pulp_importer_response import PulpImporterResponse
from crc-pulpcore-client.models.purge import Purge
from crc-pulpcore-client.models.rbac_content_guard import RBACContentGuard
from crc-pulpcore-client.models.rbac_content_guard_response import RBACContentGuardResponse
from crc-pulpcore-client.models.reclaim_space import ReclaimSpace
from crc-pulpcore-client.models.redis_connection_response import RedisConnectionResponse
from crc-pulpcore-client.models.repair import Repair
from crc-pulpcore-client.models.repository_add_remove_content import RepositoryAddRemoveContent
from crc-pulpcore-client.models.repository_response import RepositoryResponse
from crc-pulpcore-client.models.repository_version_response import RepositoryVersionResponse
from crc-pulpcore-client.models.role import Role
from crc-pulpcore-client.models.role_response import RoleResponse
from crc-pulpcore-client.models.set_label import SetLabel
from crc-pulpcore-client.models.set_label_response import SetLabelResponse
from crc-pulpcore-client.models.signing_service_response import SigningServiceResponse
from crc-pulpcore-client.models.states_enum import StatesEnum
from crc-pulpcore-client.models.status_response import StatusResponse
from crc-pulpcore-client.models.storage_class_enum import StorageClassEnum
from crc-pulpcore-client.models.storage_response import StorageResponse
from crc-pulpcore-client.models.task_group_operation_response import TaskGroupOperationResponse
from crc-pulpcore-client.models.task_group_response import TaskGroupResponse
from crc-pulpcore-client.models.task_response import TaskResponse
from crc-pulpcore-client.models.task_schedule_response import TaskScheduleResponse
from crc-pulpcore-client.models.unset_label import UnsetLabel
from crc-pulpcore-client.models.unset_label_response import UnsetLabelResponse
from crc-pulpcore-client.models.upload import Upload
from crc-pulpcore-client.models.upload_chunk_response import UploadChunkResponse
from crc-pulpcore-client.models.upload_commit import UploadCommit
from crc-pulpcore-client.models.upload_detail_response import UploadDetailResponse
from crc-pulpcore-client.models.upload_response import UploadResponse
from crc-pulpcore-client.models.upstream_pulp import UpstreamPulp
from crc-pulpcore-client.models.upstream_pulp_response import UpstreamPulpResponse
from crc-pulpcore-client.models.user import User
from crc-pulpcore-client.models.user_group import UserGroup
from crc-pulpcore-client.models.user_group_response import UserGroupResponse
from crc-pulpcore-client.models.user_response import UserResponse
from crc-pulpcore-client.models.user_role import UserRole
from crc-pulpcore-client.models.user_role_response import UserRoleResponse
from crc-pulpcore-client.models.version_response import VersionResponse
from crc-pulpcore-client.models.worker_response import WorkerResponse



# flake8: noqa

# import apis into api package
from crc-pulpcore-client.api.access_policies_api import AccessPoliciesApi
from crc-pulpcore-client.api.artifacts_api import ArtifactsApi
from crc-pulpcore-client.api.content_api import ContentApi
from crc-pulpcore-client.api.content_openpgp_publickey_api import ContentOpenpgpPublickeyApi
from crc-pulpcore-client.api.content_openpgp_publicsubkey_api import ContentOpenpgpPublicsubkeyApi
from crc-pulpcore-client.api.content_openpgp_signature_api import ContentOpenpgpSignatureApi
from crc-pulpcore-client.api.content_openpgp_userattribute_api import ContentOpenpgpUserattributeApi
from crc-pulpcore-client.api.content_openpgp_userid_api import ContentOpenpgpUseridApi
from crc-pulpcore-client.api.contentguards_api import ContentguardsApi
from crc-pulpcore-client.api.contentguards_composite_api import ContentguardsCompositeApi
from crc-pulpcore-client.api.contentguards_content_redirect_api import ContentguardsContentRedirectApi
from crc-pulpcore-client.api.contentguards_header_api import ContentguardsHeaderApi
from crc-pulpcore-client.api.contentguards_rbac_api import ContentguardsRbacApi
from crc-pulpcore-client.api.distributions_api import DistributionsApi
from crc-pulpcore-client.api.distributions_artifacts_api import DistributionsArtifactsApi
from crc-pulpcore-client.api.distributions_openpgp_api import DistributionsOpenpgpApi
from crc-pulpcore-client.api.domains_api import DomainsApi
from crc-pulpcore-client.api.exporters_filesystem_api import ExportersFilesystemApi
from crc-pulpcore-client.api.exporters_filesystem_exports_api import ExportersFilesystemExportsApi
from crc-pulpcore-client.api.exporters_pulp_api import ExportersPulpApi
from crc-pulpcore-client.api.exporters_pulp_exports_api import ExportersPulpExportsApi
from crc-pulpcore-client.api.groups_api import GroupsApi
from crc-pulpcore-client.api.groups_roles_api import GroupsRolesApi
from crc-pulpcore-client.api.groups_users_api import GroupsUsersApi
from crc-pulpcore-client.api.importers_pulp_api import ImportersPulpApi
from crc-pulpcore-client.api.importers_pulp_import_check_api import ImportersPulpImportCheckApi
from crc-pulpcore-client.api.importers_pulp_imports_api import ImportersPulpImportsApi
from crc-pulpcore-client.api.livez_api import LivezApi
from crc-pulpcore-client.api.login_api import LoginApi
from crc-pulpcore-client.api.orphans_api import OrphansApi
from crc-pulpcore-client.api.orphans_cleanup_api import OrphansCleanupApi
from crc-pulpcore-client.api.publications_api import PublicationsApi
from crc-pulpcore-client.api.remotes_api import RemotesApi
from crc-pulpcore-client.api.repair_api import RepairApi
from crc-pulpcore-client.api.repositories_api import RepositoriesApi
from crc-pulpcore-client.api.repositories_openpgp_keyring_api import RepositoriesOpenpgpKeyringApi
from crc-pulpcore-client.api.repositories_reclaim_space_api import RepositoriesReclaimSpaceApi
from crc-pulpcore-client.api.repository_versions_api import RepositoryVersionsApi
from crc-pulpcore-client.api.roles_api import RolesApi
from crc-pulpcore-client.api.signing_services_api import SigningServicesApi
from crc-pulpcore-client.api.status_api import StatusApi
from crc-pulpcore-client.api.task_groups_api import TaskGroupsApi
from crc-pulpcore-client.api.task_schedules_api import TaskSchedulesApi
from crc-pulpcore-client.api.tasks_api import TasksApi
from crc-pulpcore-client.api.uploads_api import UploadsApi
from crc-pulpcore-client.api.upstream_pulps_api import UpstreamPulpsApi
from crc-pulpcore-client.api.users_api import UsersApi
from crc-pulpcore-client.api.users_roles_api import UsersRolesApi
from crc-pulpcore-client.api.workers_api import WorkersApi




# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from crc-pulpcore-client.models.policy357_enum import Policy357Enum
from typing import Optional, Set
from typing_extensions import Self

class UpstreamPulp(BaseModel):
    """
    Serializer for a Server.
    """ # noqa: E501
    name: Annotated[str, Field(min_length=1, strict=True)] = Field(description="A unique name for this Pulp server.")
    base_url: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The transport, hostname, and an optional port of the Pulp server. e.g. https://example.com")
    api_root: Annotated[str, Field(min_length=1, strict=True)] = Field(description="The API root. Defaults to '/pulp/'.")
    domain: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The domain of the Pulp server if enabled.")
    ca_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded CA certificate used to validate the server certificate presented by the remote server.")
    client_cert: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded client certificate used for authentication.")
    client_key: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="A PEM encoded private key used for authentication.")
    tls_validation: Optional[StrictBool] = Field(default=None, description="If True, TLS peer validation must be performed.")
    username: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The username to be used for authentication when syncing.")
    password: Optional[Annotated[str, Field(min_length=1, strict=True)]] = Field(default=None, description="The password to be used for authentication when syncing. Extra leading and trailing whitespace characters are not trimmed.")
    q_select: Optional[StrictStr] = Field(default=None, description="Filter distributions on the upstream Pulp using complex filtering. E.g. pulp_label_select=\"foo\" OR pulp_label_select=\"key=val\"")
    policy: Optional[Policy357Enum] = Field(default=None, description="Policy for how replicate will manage the local objects within the domain.  * `all` - Replicate manages ALL local objects within the domain. * `labeled` - Replicate will only manage the objects created from a previous replication, unlabled local objects will be untouched. * `nodelete` - Replicate will not delete any local object whether they were created by replication or not.")
    __properties: ClassVar[List[str]] = ["name", "base_url", "api_root", "domain", "ca_cert", "client_cert", "client_key", "tls_validation", "username", "password", "q_select", "policy"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UpstreamPulp from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if domain (nullable) is None
        # and model_fields_set contains the field
        if self.domain is None and "domain" in self.model_fields_set:
            _dict['domain'] = None

        # set to None if ca_cert (nullable) is None
        # and model_fields_set contains the field
        if self.ca_cert is None and "ca_cert" in self.model_fields_set:
            _dict['ca_cert'] = None

        # set to None if client_cert (nullable) is None
        # and model_fields_set contains the field
        if self.client_cert is None and "client_cert" in self.model_fields_set:
            _dict['client_cert'] = None

        # set to None if client_key (nullable) is None
        # and model_fields_set contains the field
        if self.client_key is None and "client_key" in self.model_fields_set:
            _dict['client_key'] = None

        # set to None if username (nullable) is None
        # and model_fields_set contains the field
        if self.username is None and "username" in self.model_fields_set:
            _dict['username'] = None

        # set to None if password (nullable) is None
        # and model_fields_set contains the field
        if self.password is None and "password" in self.model_fields_set:
            _dict['password'] = None

        # set to None if q_select (nullable) is None
        # and model_fields_set contains the field
        if self.q_select is None and "q_select" in self.model_fields_set:
            _dict['q_select'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UpstreamPulp from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "base_url": obj.get("base_url"),
            "api_root": obj.get("api_root"),
            "domain": obj.get("domain"),
            "ca_cert": obj.get("ca_cert"),
            "client_cert": obj.get("client_cert"),
            "client_key": obj.get("client_key"),
            "tls_validation": obj.get("tls_validation"),
            "username": obj.get("username"),
            "password": obj.get("password"),
            "q_select": obj.get("q_select"),
            "policy": obj.get("policy")
        })
        return _obj





# coding: utf-8

"""
    Pulp 3 API

    Fetch, Upload, Organize, and Distribute Software Packages

    The version of the OpenAPI document: v3
    Contact: pulp-list@redhat.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "crc-pulpcore-client"
VERSION = "20250821.1"
PYTHON_REQUIRES = ">= 3.8"
REQUIRES = [
    "urllib3 >= 1.25.3, < 3.0.0",
    "python-dateutil >= 2.8.1, < 2.10.0",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Pulp 3 API",
    author="Pulp Team",
    author_email="pulp-list@redhat.com",
    url="",
    keywords=["pulp", "pulpcore", "client", "Pulp 3 API"],
    install_requires=REQUIRES,
    python_required=PYTHON_REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="GPLv2+",
    long_description_content_type='text/markdown',
    long_description="""\
    Fetch, Upload, Organize, and Distribute Software Packages
    """,  # noqa: E501
    package_data={"crc-pulpcore-client": ["py.typed"]},
)
